@@ -26,13 +26,10 @@ def generate_matched_gaussian_bunch(num_particles,
                                     tracker=None,
                                     particle_ref=None,
                                     particles_class=None,
-                                    co_search_settings=None,
-                                    steps_r_matrix=None,
                                     _context=None, _buffer=None, _offset=None,
+                                    **kwargs, # They are passed to build_particles
                                     ):
 
-    Particles = xp.Particles # To get the right Particles class depending on pyheatail interface state
-
     if (particle_ref is not None and particle_on_co is not None):
         raise ValueError("`particle_ref` and `particle_on_co`"
                 " cannot be provided at the same time")
@@ -58,7 +55,8 @@ def generate_matched_gaussian_bunch(num_particles,
             rf_voltage=rf_voltage,
             rf_phase=rf_phase,
             p_increment=p_increment,
-            sigma_z=sigma_z)
+            sigma_z=sigma_z,
+            **kwargs)
 
     assert len(zeta) == len(delta) == num_particles
 
@@ -84,6 +82,5 @@ def generate_matched_gaussian_bunch(num_particles,
                       y_norm=y_norm, py_norm=py_norm,
                       scale_with_transverse_norm_emitt=(nemitt_x, nemitt_y),
                       weight=total_intensity_particles/num_particles,
-                      co_search_settings=co_search_settings,
-                      steps_r_matrix=steps_r_matrix)
+                      **kwargs)
     return part
